@@ -10,7 +10,7 @@ if os.path.isdir(DIR):
 
 import unittest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view
+from trytond.tests.test_tryton import test_view, test_depends
 
 
 class AccountInvoiceLineStandaloneTestCase(unittest.TestCase):
@@ -26,8 +26,13 @@ class AccountInvoiceLineStandaloneTestCase(unittest.TestCase):
         '''
         Test views.
         '''
-        self.assertRaises(Exception, test_view(
-            'account_invoice_line_standalone'))
+        test_view('account_invoice_line_standalone')
+
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
 
 def suite():
     suite = trytond.tests.test_tryton.suite()
